@@ -52,7 +52,7 @@ def bq_to_df(sql, client=None, **job_config):
         job = client.query(sql, job_id=job_id, job_config=job_config)
         # job.result()
         df = job.to_dataframe()
-        # job_info = bq_job_info(job,client=client) #dependency
+        # job_info = bq_get_job_info(job,client=client) #dependency
         date_columns = get_date_columns(job)
 
         if date_columns:
@@ -63,12 +63,12 @@ def bq_to_df(sql, client=None, **job_config):
             'adhoc script request')  # dependency
         job = client.query(sql, job_id=job_id, job_config=job_config)
         job.result()
-        job_id = bq_job_info(job, client=client,
-                             output_option='LIST')  # dependency
+        job_id = bq_get_job_info(job, client=client,
+                                 output_option='LIST')  # dependency
 
         if len(job_id) == 1:
             df = client.get_job(job_id[0]).to_dataframe()
-            # job_info = bq_job_info(job,client=client) #dependency
+            # job_info = bq_get_job_info(job,client=client) #dependency
             date_columns = get_date_columns(job)
 
             if date_columns:
@@ -76,7 +76,7 @@ def bq_to_df(sql, client=None, **job_config):
 
         elif len(job_id) > 1:
             df = client.get_job(job_id[-1]).to_dataframe()
-            # job_info = bq_job_info(job,client=client) #dependency
+            # job_info = bq_get_job_info(job,client=client) #dependency
             logging.waring(
                 " multi select stored procedure returns data for the last SELECT statement only")
             date_columns = get_date_columns(job)
@@ -91,7 +91,7 @@ def bq_to_df(sql, client=None, **job_config):
         logging.error(
             f"{job.statement_type} are not suppoted. Please provide a SELECT statement or a stored procedure containing SELECT statement")
         return
-        # job_info = bq_job_info(job,client=client) #dependency
+        # job_info = bq_get_job_info(job,client=client) #dependency
         # logging.info(f"job execution detail: {job_info}")
     logging.info(f"{job.statement_type} statement returned {len(df)} rows")
 
@@ -228,7 +228,8 @@ def bq_to_excel(sql, filepath=None, sheet_name=None, index=False, mode='w', clie
     job.result()
 
     if job.statement_type == 'SCRIPT':
-        select_job_ids = bq_job_info(job, output_option='LIST')  # dependency
+        select_job_ids = bq_get_job_info(
+            job, output_option='LIST')  # dependency
         dfs = [client.get_job(job_id).to_dataframe()
                for job_id in select_job_ids]
     else:
@@ -281,7 +282,7 @@ def bq_to_csv(sql, filepath=None, header=True, client=None, output_option='FILE'
     return filepath
 
 
-def bq_job_info(job, client=None, output_option=None):
+def bq_get_job_info(job, client=None, output_option=None):
     """Return bigquery job info.
 
         For query jobs: 
@@ -302,10 +303,10 @@ def bq_job_info(job, client=None, output_option=None):
         dict | list -- job info is dict, while children job info is list
 
     Example:
-    bq_job_info(client.query(sql_statement)) # returns job_info
+    bq_get_job_info(client.query(sql_statement)) # returns job_info
 
     # for SCRIPT, returns detail of children jobs of SELECT statements type
-    bq_job_info(script_job, output_option='DICT')
+    bq_get_job_info(script_job, output_option='DICT')
 
     """
     if not client:
